@@ -959,10 +959,29 @@ public class RootTree : Tree {
 		}
 	}
 	
-	public bool GetNamespaceAndType (string url, out string ns, out string type)
+	public static bool GetNamespaceAndType (string url, out string ns, out string type)
 	{
-		int nsidx = url.LastIndexOf (".");
-		if (nsidx == -1){
+		int nsidx = -1;
+		int numLt = 0;
+		for (int i = 0; i < url.Length; ++i) {
+			char c = url [i];
+			switch (c) {
+			case '<':
+			case '{':
+				++numLt;
+				break;
+			case '>':
+			case '}':
+				--numLt;
+				break;
+			case '.':
+				if (numLt == 0)
+					nsidx = i;
+				break;
+			}
+		}
+
+		if (nsidx == -1) {
 			Console.Error.WriteLine ("Did not find dot in: " + url);
 			ns = null;
 			type = null;
@@ -1299,11 +1318,20 @@ public class RootTree : Tree {
 			}
 		}
 
-		// No octal in C#, how lame is that
-		chmod (path, 0x1a4);
+		if (IsUnix){
+			// No octal in C#, how lame is that
+			chmod (path, 0x1a4);
+		}
 		Console.WriteLine ("Documentation index updated");
 	}
-	
+
+	static bool IsUnix {
+		get {
+			int p = (int) Environment.OSVersion.Platform;
+			return ((p == 4) || (p == 128));
+                }
+        }
+
 	// Search Index
 	public SearchableIndex GetSearchIndex ()
 	{
